package com.sztzjy.money_management.util;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageInfo;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;

import java.util.ArrayList;
import java.util.List;

/**
 * 分页工具类
 */
public class PageUtil {
    private final Integer index;
    private final Integer size;
    private Sort sort;


    /*
     * @author xcj
     * @Date 2023/9/9
     */
    //直接给list分页
    public static PageInfo pageHelper(List list, Integer pageNum, Integer pageSize){
        Page page = new Page(pageNum, pageSize);
        int total = list.size();
        page.setTotal(total);
        int startIndex = (pageNum - 1) * pageSize;
        int endIndex = Math.min(startIndex + pageSize,total);
        if(startIndex>endIndex){
            page.addAll(new ArrayList());
            PageInfo pageInfo = new PageInfo<>(page);
            return pageInfo;
        }else{
            page.addAll(list.subList(startIndex,endIndex));
            PageInfo pageInfo = new PageInfo<>(page);
            return pageInfo;
        }
    }


    public PageUtil(Integer index, Integer size) {
        if (index == null || index < 0) index = 0;
        if (size == null || size < 0) size = 10;
        if (size > 200) size = 1000;
        this.index = index;
        this.size = size;
    }

    //该方法用于数据量大的情况下分页导出
    public PageUtil(Integer index, Integer size, boolean type) {
        if (index == null || index < 0) index = 0;
        if (size == null || size < 0) size = 10;
        this.index = index;
        this.size = size;
    }

    public void addSort(String columnName, Boolean asc) {
        Sort.Direction direction = Sort.Direction.ASC;
        if (!asc) direction = Sort.Direction.DESC;
        if (sort == null) {
            sort = Sort.by(direction, columnName);
        } else {
            sort = sort.and(Sort.by(direction, columnName));
        }
    }

    public Pageable getPageable() {
        if (sort == null)
            return PageRequest.of(index, size);
        else
            return PageRequest.of(index, size, sort);
    }


}
